@@ -1,8 +1,7 @@
-from __future__ import unicode_literals
+from django.contrib.auth import get_user_model
 from django.contrib.contenttypes.models import ContentType
 from django.test import TestCase
 
-from guardian.compat import get_user_model
 from guardian.shortcuts import assign_perm, remove_perm
 
 
