@@ -3,7 +3,8 @@ import os
 import sys
 
 if __name__ == "__main__":
-    os.environ.setdefault("DJANGO_SETTINGS_MODULE", "guardian.testapp.testsettings")
+    os.environ.setdefault("DJANGO_SETTINGS_MODULE",
+                          "guardian.testapp.testsettings")
 
     from django.core.management import execute_from_command_line
 
