@@ -1,4 +1,3 @@
-
 def show_settings(settings, action):
     import guardian
     from django.utils.termcolors import colorize
@@ -8,7 +7,7 @@ def show_settings(settings, action):
     print(colorize(msg, fg='magenta'))
     db_conf = settings.DATABASES['default']
     output = []
-    msg = "Starting %s for db backend: %s" % (action, db_conf['ENGINE'])
+    msg = "Starting {} for db backend: {}".format(action, db_conf['ENGINE'])
     embracer = '=' * len(msg)
     output.append(msg)
     for key in sorted(db_conf.keys()):
@@ -16,7 +15,7 @@ def show_settings(settings, action):
             value = '****************'
         else:
             value = db_conf[key]
-        line = '    %s: "%s"' % (key, value)
+        line = '    {}: "{}"'.format(key, value)
         output.append(line)
     embracer = colorize('=' * len(max(output, key=lambda s: len(s))),
                         fg='green', opts=['bold'])
